/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views;

import static java.util.Collections.emptyList;

import java.util.Collection;

import org.eclipse.fx.ui.workbench3.FXViewPart;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeContentProviderBase;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeUIProviderBase;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeViewer;

import javafx.scene.Scene;
import javafx.scene.control.TextField;
import javafx.scene.layout.BorderPane;

/**
 * {@link FXViewPart} for showing composable model elements with DND editing support.
 * 
 * @author hoelzl
 */
public final class LibraryViewFX extends FXViewPart {
	/** The tree-table viewer. */
	private DynamicTreeViewer<Object> treeViewer;
	/** The filter text field if filtering is enabled in content provider. */
	private TextField filterWidget;

	/** {@inheritDoc} */
	@Override
	protected Scene createFxScene() {
		BorderPane pane = new BorderPane();

		filterWidget = new TextField();
		filterWidget.textProperty().addListener((obs, oVal, nVal) -> {
			// contentProvider.setFilterExpression(nVal);
			treeViewer.update();
		});

		treeViewer = new DynamicTreeViewer<>(new Object(), true, 2, new LibraryContentProvider(),
				new LibraryUIProvider());

		pane.setTop(filterWidget);
		pane.setCenter(treeViewer.getControl());

		return new Scene(pane);
	}

	/** {@inheritDoc} */
	@Override
	protected void setFxFocus() {
		filterWidget.requestFocus();
	}

	/** {@link DynamicTreeContentProviderBase} for the library view. */
	private class LibraryContentProvider extends DynamicTreeContentProviderBase<Object> {
		/** {@inheritDoc} */
		@Override
		protected Collection<? extends Object> getChildren(Object parent) {
			return emptyList(); // FIXME
		}
	}

	/** {@link DynamicTreeUIProviderBase} for the library view. */
	private class LibraryUIProvider extends DynamicTreeUIProviderBase<Object> {
		// TODO: go on here
	}
}
